@@ -28,6 +28,7 @@ from turberfield.dialogue.directives import Entity
 from turberfield.dialogue.model import Model
 from turberfield.dialogue.model import SceneScript
 from turberfield.dialogue.performer import Performer
+from turberfield.dialogue.types import DataObject
 from turberfield.dialogue.types import EnumFactory
 from turberfield.dialogue.types import Stateful
 from turberfield.dialogue.types import Player
@@ -378,11 +379,12 @@ class ConditionDirectiveTests(unittest.TestCase):
         script.cast(selection)
         model = script.run()
         conditions = [l for s, l in model if isinstance(l, Model.Condition)]
-        self.assertEqual(3, len(conditions))
+        self.assertEqual(4, len(conditions))
 
         self.assertTrue(Performer.allows(conditions[0]))
         self.assertFalse(Performer.allows(conditions[1]))
-        self.assertTrue(Performer.allows(conditions[2]))
+        self.assertFalse(Performer.allows(conditions[2]))
+        self.assertTrue(Performer.allows(conditions[3]))
 
     def test_condition_evaluation_two(self):
         effects = [
@@ -397,13 +399,87 @@ class ConditionDirectiveTests(unittest.TestCase):
         script.cast(selection)
         model = script.run()
         conditions = [l for s, l in model if isinstance(l, Model.Condition)]
-        self.assertEqual(3, len(conditions))
+        self.assertEqual(4, len(conditions))
 
         self.assertTrue(Performer.allows(conditions[0]))
-        self.assertTrue(Performer.allows(conditions[1]))
-        self.assertFalse(Performer.allows(conditions[2]))
+        self.assertFalse(Performer.allows(conditions[1]))
+        self.assertTrue(Performer.allows(conditions[2]))
+        self.assertFalse(Performer.allows(conditions[3]))
 
 
+class ConditionSyntaxTests(unittest.TestCase):
+
+    def test_exact_matching(self):
+        content = textwrap.dedent("""
+            .. entity:: WHATEVER
+
+            Test exact
+            ~~~~~~~~~~
+
+            One
+            ---
+
+            .. condition:: WHATEVER.value 1
+
+            One.
+
+            Two
+            ---
+
+            .. condition:: WHATEVER.value 2
+
+            Two.
+
+        """)
+        script = SceneScript("inline", doc=SceneScript.read(content))
+        selection = script.select([DataObject(value=1)])
+        self.assertTrue(all(selection.values()))
+        script.cast(selection)
+        model = script.run()
+        conditions = [l for s, l in model if isinstance(l, Model.Condition)]
+        self.assertEqual(2, len(conditions))
+
+        self.assertTrue(Performer.allows(conditions[0]))
+        self.assertFalse(Performer.allows(conditions[1]))
+
+    def test_regex_matching(self):
+        content = textwrap.dedent("""
+            .. entity:: WHATEVER
+
+            Test exact
+            ~~~~~~~~~~
+
+            Odd
+            ---
+
+            .. condition:: WHATEVER.value ([13579])
+
+            Odd.
+
+            Even
+            ----
+
+            .. condition:: WHATEVER.value ([02468])
+
+            Even.
+
+        """)
+        obj = DataObject(value=1)
+        script = SceneScript("inline", doc=SceneScript.read(content))
+        selection = script.select([obj])
+        self.assertTrue(all(selection.values()))
+        script.cast(selection)
+        model = script.run()
+        conditions = [l for s, l in model if isinstance(l, Model.Condition)]
+        self.assertEqual(2, len(conditions))
+
+        self.assertTrue(Performer.allows(conditions[0]), conditions[0])
+        self.assertFalse(Performer.allows(conditions[1]))
+
+        obj.value = 2
+        self.assertFalse(Performer.allows(conditions[0]), conditions[0])
+        self.assertTrue(Performer.allows(conditions[1]))
+
 class FXDirectiveTests(unittest.TestCase):
 
     def test_fx_audio(self):
